@@ -11,8 +11,7 @@ geolitecity_url = 'http://geolite.maxmind.com/download/geoip/database/GeoLiteCit
 geolitecity_update = 2592000
 squid_cleanse_interval = 15
 squid_inactive_time = 180
-amqp_server_url = 'localhost'
-amqp_server_port = 5672
+amqp_server_url = 'amqp://guest:guest@localhost:5672/%2F'
 amqp_server_queue = 'squiddata'
 amqp_exchange = 'shoal'
 amqp_exchange_type = 'topic'
@@ -29,7 +28,6 @@ def setup(path=None):
     global squid_cleanse_interval
     global squid_inactive_time
     global amqp_server_url
-    global amqp_server_port
     global amqp_server_queue
     global amqp_exchange
     global amqp_exchange_type
@@ -112,14 +110,6 @@ def setup(path=None):
         amqp_server_url = config_file.get("rabbitmq",
                                                 "amqp_server_url")
 
-    if config_file.has_option("rabbitmq", "amqp_server_port"):
-        try:
-            amqp_server_port = config_file.getint("rabbitmq", "amqp_server_port")
-        except ValueError:
-            print "Configuration file problem: amqp_port must be an " \
-                  "integer value."
-            sys.exit(1)
-
     if config_file.has_option("rabbitmq", "amqp_server_queue"):
         amqp_server_queue = config_file.get("rabbitmq",
                                                 "amqp_server_queue")
